@@ -30,10 +30,9 @@ if float(URWID_VERSION[0] + "." + URWID_VERSION[1]) < 1.1:
     exit(1)
 
 try:
-    import util
-    import search
-except ImportError:
     from fastcd import util, search
+except ImportError:
+    from . import util, search
 
 
 DESC = '''
@@ -466,9 +465,10 @@ class Display(object):
         if check_existence:
             util.print_status("Checking the existence of directories...", truncate=True)
 
+        skip_set = ('', cwd, oldpwd)
         for line in entries:
             path = line.strip()
-            if path in [cwd, oldpwd]:
+            if path in skip_set:
                 continue
             if check_existence:
                 exists = os.path.exists(expanduser(path))
